Documentation
¶
Overview ¶
Package forkcleaner provides functions to find and remove unused forks.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type RepositoryWithDetails ¶
type RepositoryWithDetails struct {
Name string
ParentName string
RepoURL string
Private bool
ParentDeleted bool
ParentDMCATakeDown bool
Forks int
Stars int
OpenPRs int
CommitsAhead int
LastUpdate time.Time
}
func FindAllForks ¶
func FindAllForks(ctx context.Context, client *github.Client, login string, skipUpstream bool) ([]*RepositoryWithDetails, error)
FindAllForks lists all the forks for the current user.
Click to show internal directories.
Click to hide internal directories.